@@ -5,9 +5,9 @@ use strict;
 use utf8;
 use Carp;
 
-our $VERSION = 'v2.0.0';
+our $VERSION = 'v2.1.0';
 
-use JSON::XS;
+use JSON::MaybeXS;
 
 use constant ERR_PARSE  => -32700;
 use constant ERR_REQ    => -32600;
@@ -204,7 +204,7 @@ JSON::RPC2::Server - Transport-independent JSON-RPC 2.0 server
 
 =head1 VERSION
 
-This document describes JSON::RPC2::Server version v2.0.0
+This document describes JSON::RPC2::Server version v2.1.0
 
 
 =head1 SYNOPSIS
